@@ -72,9 +72,8 @@ OC.L10N.register(
     "Writing mode" : "Način pisanja",
     "Preferred writing mode for new messages and replies." : "Prednostni način pisanja sporočil za nova sporočila in odgovore.",
     "Default folders" : "Privzete mape",
-    "Sieve filter rules" : "Pravila filtra Sieve",
+    "Filters" : "Filtri",
     "Mail server" : "Poštni strežnik",
-    "Sieve filter server" : "Strežnik filtra Sieve",
     "Mailbox search" : "Iskanje po poštnem predalu",
     "Update alias" : "Posodobi vzdevek",
     "Rename alias" : "Preimenuj vzdevek",
@@ -87,22 +86,23 @@ OC.L10N.register(
     "Create alias" : "Ustvari vzdevek",
     "Cancel" : "Prekliči",
     "Mail settings" : "Nastavitve pošte",
-    "List" : "Seznam",
-    "Account creation" : "Ustvarjanje računa",
+    "Accounts" : "Računi",
     "Add mail account" : "Dodaj račun elektronske pošte",
-    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
-    "Trusted senders" : "Zaupanja vredni pošiljatelji",
+    "General" : "Splošno",
+    "List" : "Seznam",
+    "Sorting" : "Razvrščanje",
+    "Newest" : "Najnovejše",
+    "Oldest" : "Najstarejše",
     "Gravatar settings" : "Nastavitve Gravatar",
     "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
     "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
     "Register" : "Vpis računa",
+    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
+    "Trusted senders" : "Zaupanja vredni pošiljatelji",
     "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
-    "Sorting" : "Razvrščanje",
-    "Newest" : "Najnovejše",
-    "Oldest" : "Najstarejše",
     "Looking for a way to encrypt your emails?" : "Ali iščete način za šifriranje elektronskih sporočil?",
-    "Keyboard" : "Tipkovnica",
+    "Keyboard shortcuts" : "Tipkovne bližnjice",
     "Compose new message" : "Novo sporočilo",
     "Newer message" : "Novejše sporočilo",
     "Older message" : "Starejše sporočilo",
@@ -114,7 +114,6 @@ OC.L10N.register(
     "Send" : "Pošlji",
     "Refresh" : "Osveži",
     "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
-    "Automatically classify importance of new email" : "Samodejno določi pomembnost novih sporočil",
     "Could not update preference" : "Lastnosti ni mogoče posodobiti",
     "Select an alias" : "Izbor vzdevka",
     "Update Certificate" : "Posodobi potrdilo",
@@ -127,7 +126,6 @@ OC.L10N.register(
     "To" : "Za",
     "Select recipient" : "Izbor prejemnika",
     "Contact or email address …" : "Stik ali elektronski naslov ...",
-    "Toggle recipients list mode" : "Preklopi način seznama prejemnikov",
     "Cc" : "Kp",
     "Bcc" : "Skp",
     "Subject" : "Zadeva",
@@ -145,6 +143,7 @@ OC.L10N.register(
     "Disable formatting" : "Onemogoči oblikovanje",
     "Upload attachment" : "Pošlji prilogo",
     "Add attachment from Files" : "Dodaj prilogo iz Datotek",
+    "Smart picker" : "Pametni izbirnik",
     "Send later" : "Pošlji kasneje",
     "Request a read receipt" : "Zahtevaj povratnico",
     "Sign message with S/MIME" : "Podpiši sporočila z S/MIME",
@@ -156,7 +155,6 @@ OC.L10N.register(
     "Monday morning" : "Ponedeljek zjutraj",
     "Custom date and time" : "Datum in čas po meri",
     "Enter a date" : "Vpis datuma ...",
-    "Add share link from {productName} Files" : "Dodaj mapo do mesta souporabe datotek {productName}",
     "Encrypt with S/MIME and send later" : "Šifriraj z S/MIME in pošlji kasneje",
     "Encrypt with S/MIME and send" : "Šifriraj z S/MIME in pošlji",
     "Encrypt with Mailvelope and send later" : "Šifriraj z Mailvelope in pošlji kasneje",
@@ -169,7 +167,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Izberite datoteko, ki jo želite dati v skupno rabo kot povezavo",
     "Choose" : "Izbor",
     "_{count} attachment_::_{count} attachments_" : ["{count} priloga","{count} prilogi","{count} priloge","{count} prilog"],
-    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Velikost priloge presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave.","Velikost prilog presega dovoljeno vrednost {size}. Priporočljivo je omogočiti souporabo prek povezave."],
     "Untitled message" : "Nenaslovljeno sporočilo",
     "Confirm" : "Potrdi",
     "Plain text" : "Besedilno",
@@ -186,8 +183,6 @@ OC.L10N.register(
     "Unimportant" : "Nepomembno",
     "Mark not spam" : "Označi kot običajno",
     "Mark as spam" : "Označi kot neželeno",
-    "Unselect" : "Odstrani izbor",
-    "Select" : "Izbor",
     "Edit tags" : "Uredi oznake",
     "Move thread" : "Premakni nit",
     "Archive thread" : "Nit arhiva",
@@ -207,16 +202,14 @@ OC.L10N.register(
     "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
     "Could not delete message" : "Sporočila ni mogoče izbrisati",
     "Could not archive message" : "Ni mogoče arhivirati sporočila",
-    "Forward" : "Posreduj",
     "Load more" : "Naloži več",
-    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} sporočilo kot neprebrano","Označi {number} sporočili kot neprebrani","Označi {number} sporočila kot neprebrana","Označi {number} sporočil kot neprebrana"],
     "_Mark {number} read_::_Mark {number} read_" : ["Označi {number} sporočilo kot prebrano","Označi {number} sporočili kot prebrani","Označi {number} sporočila kot prebrana","Označi {number} sporočil kot prebrana"],
+    "_Mark {number} unread_::_Mark {number} unread_" : ["Označi {number} sporočilo kot neprebrano","Označi {number} sporočili kot neprebrani","Označi {number} sporočila kot neprebrana","Označi {number} sporočil kot neprebrana"],
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Odstrani oznako {number} sporočila kot priljubljenega","Odstrani oznako {number} sporočil kot priljubljenih","Odstrani oznako {number} sporočil kot priljubljenih","Odstrani oznako {number} sporočil kot priljubljenih"],
     "_Favorite {number}_::_Favorite {number}_" : ["Označi {number} sporočilo kot priljubljeno","Označi {number} sporočili kot priljubljeni","Označi {number} sporočila kot priljubljena","Označi {number} sporočil kot priljubljena"],
     "_Unselect {number}_::_Unselect {number}_" : ["Odstrani izbiro {number} sporočila","Odstrani izbiro {number} sporočil","Odstrani izbiro {number} sporočil","Odstrani izbiro {number} sporočil"],
     "_Move {number} thread_::_Move {number} threads_" : ["Premakni {number} nit sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil","Premakni {number} niti sporočil"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Posreduj {number} sporočilo kot prilogo","Posreduj {number} sporočili kot prilogo","Posreduj {number} sporočila kot prilogo","Posreduj {number} sporočil kot prilogo"],
-    "_Delete {number} thread_::_Delete {number} threads_" : ["Izbriši {number} nit sporočil","Izbriši {number} niti sporočil","Izbriši {number} niti sporočil","Izbriši {number} niti sporočil"],
     "Report this bug" : "Pošlji poročilo o hrošču",
     "All day" : "Ves dan",
     "Select calendar" : "Izbor koledarja",
@@ -231,6 +224,7 @@ OC.L10N.register(
     "You have been invited to an event" : "Povabljeni ste na dogodek",
     "This event was cancelled" : "Dogodek je preklican",
     "Save to" : "Shrani v",
+    "Select" : "Izbor",
     "Comment" : "Opomba",
     "Accept" : "Sprejmi",
     "Decline" : "Zavrni",
@@ -243,6 +237,11 @@ OC.L10N.register(
     "{attendeeName} declined your invitation" : "{attendeeName} zavrne povabilo",
     "{attendeeName} reacted to your invitation" : "{attendeeName} se odzove na povabilo",
     "Failed to save your participation status" : "Shranjevanje stanja udeležbe je spodletelo",
+    "domain" : "domena",
+    "Remove" : "Odstrani",
+    "email" : "elektronska pošta",
+    "individual" : "posamično",
+    "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
     "Could not open mailbox" : "Ni mogoče odpreti poštnega predala",
     "Loading messages …" : "Poteka nalaganje sporočil ...",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Poteka ustvarjanje kazala sporočil. Opravilo je lahko dolgotrajno pri velikih poštnih predalih.",
@@ -255,25 +254,22 @@ OC.L10N.register(
     "Notify the sender" : "Obvesti pošiljatelja",
     "You sent a read confirmation to the sender of this message." : "Poslali ste potrditev pošiljatelju tega sporočila.",
     "Could not send mdn" : "Sporočila ni mogoče poslati",
-    "Reply all" : "Odgovori vsem",
-    "Reply" : "Odgovori",
-    "Reply to sender only" : "Odgovori le pošiljatelju",
+    "Forward" : "Posreduj",
     "Move message" : "Premakni sporočilo",
     "Forward message as attachment" : "Posreduj sporočilo kot prilogo",
     "View source" : "Pokaži kode sporočila",
     "Download thread data for debugging" : "Prejmi podatke niti za razhroščevanje",
     "Message body" : "Telo sporočila",
+    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje priloge",
     "Import into calendar" : "Uvozi v koledar",
     "Download attachment" : "Prejmi prilogo",
     "Save to Files" : "Shrani v Datoteke",
     "Unnamed" : "Neimenovano",
     "Embedded message" : "Vstavljeno sporočilo",
-    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
-    "Choose a folder to store the attachment in" : "Izbor mape za shranjevanje priloge",
     "View fewer attachments" : "Pokaži manj prilog",
+    "Choose a folder to store the attachments in" : "Izbor mape za shranjevanje priloge",
     "Save all to Files" : "Shrani vse v Datoteke",
     "Download Zip" : "Prejmi ZIP",
-    "Choose a folder to store the attachments in" : "Izbor mape za shranjevanje priloge",
     "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Sporočilo je šifrirano s programom PGP. Za odšifriranje mora biti nameščen program Mailvelope.",
     "The images have been blocked to protect your privacy." : "Za zaščito zasebnosti je prikaz slik onemogočen.",
     "Show images" : "Pokaži slike",
@@ -298,7 +294,6 @@ OC.L10N.register(
     "Not supported by the server" : "Opravilo na strežniku ni podprto",
     "{usage} of {limit} used" : "Uporabljeno je {usage} od {limit} prostora.",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Račun za {email} in podatki tega računa v predpomnilniku bodo odstranjeni iz oblaka Nextcloud, ne pa tudi iz poštnega računa pri ponudniku storitve.",
-    "Remove account {email}" : "Odstrani račun {email}",
     "Remove {email}" : "Odstrani {email}",
     "Show all subscribed mailboxes" : "Pokaži vse naročene poštne predale",
     "Show all mailboxes" : "Pokaži vse poštne predale",
@@ -306,7 +301,7 @@ OC.L10N.register(
     "Mark all as read" : "Označi vse kot prebrano",
     "Mark all messages of this mailbox as read" : "Označi vsa sporočila v tej mapi kot prebrana",
     "Add submailbox" : "Dodaj podrejeni poštni predal",
-    "Edit name" : "Uredi ime",
+    "Rename" : "Preimenuj",
     "Move mailbox" : "Premakni poštni predal",
     "Clear cache" : "Počisti predpomnilnik",
     "Clear locally cached data, in case there are issues with synchronization." : "Počisti krajevno predpomnjena sporočila, v primeru morebitnih težav z usklajevanjem.",
@@ -320,7 +315,6 @@ OC.L10N.register(
     "Delete mailbox {name}" : "Izbriši poštni predal {name}",
     "An error occurred, unable to rename the mailbox." : "Prišlo je do napake; poštnega predala ni mogoče preimenovati.",
     "_{total} message_::_{total} messages_" : ["{total} sporočilo","{total} sporočili","{total} sporočila","{total} sporočil"],
-    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neprebrano od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebrana od skupno {total}","{unread} neprebranih od skupno {total}"],
     "Outbox" : "Odhodna pošta",
     "New message" : "Novo sporočilo",
     "Error sending your message" : "Prošlo je do napake med pošiljanjem sporočila",
@@ -331,6 +325,7 @@ OC.L10N.register(
     "Send anyway" : "Pošlji vseeno",
     "Edit message" : "Uredi sporočilo",
     "Draft" : "Osnutek",
+    "Reply" : "Odgovori",
     "Message saved" : "Sporočilo je shranjeno",
     "Failed to save message" : "Shranjevanje sporočila je spodletelo",
     "Failed to save draft" : "Shranjevanje osnutka je spodletelo",
@@ -368,22 +363,15 @@ OC.L10N.register(
     "Select tags" : "Izbor oznak",
     "Marked as" : "Označeno kot",
     "Has attachments" : "Vsebuje prilogo",
-    "Clear" : "Počisti",
     "Last 7 days" : "Zadnjih 7 dni",
-    "Disabled" : "Onemogočeno",
-    "Enabled" : "Omogočeno",
-    "Sieve Host" : "Gostitelj Sieve",
-    "Sieve Security" : "Varnost Sieve",
+    "Clear" : "Počisti",
     "Sieve Port" : "Vrata Sieve",
-    "Sieve Credentials" : "Poverila Sieve",
-    "IMAP Credentials" : "Poverila IMAP",
     "Custom" : "Po meri",
     "Sieve User" : "Uporabnik Sieve",
     "Sieve Password" : "Geslo Sieve",
     "Save sieve settings" : "Shrani nastavitve sieve",
     "Save sieve script" : "Shrani skript sieve",
     "The syntax seems to be incorrect:" : "Skladnja je videti nepravilna:",
-    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
     "Signature …" : "Podpis ...",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
     "Save signature" : "Shrani podpis",
@@ -407,6 +395,8 @@ OC.L10N.register(
     "Could not load your message thread" : "Ni mogoče naložiti niti sporočil",
     "The thread doesn't exist or has been deleted" : "Nit ne obstaja ali pa je bila izbrisana",
     "Unsubscribe" : "Prekliči naročnino",
+    "Reply all" : "Odgovori vsem",
+    "Reply to sender only" : "Odgovori le pošiljatelju",
     "Mark as unfavorite" : "Odstrani oznako priljubljeno",
     "Mark as favorite" : "Označi kot priljubljeno",
     "Mark as unread" : "Označi kot neprebrano",
@@ -417,11 +407,8 @@ OC.L10N.register(
     "Encrypted & verified " : "Šifrirano in overjeno",
     "Signature verified" : "Podpis je overjen",
     "Signature unverified " : "Podpis ni overjen",
-    "Remove" : "Odstrani",
     "No senders are trusted at the moment." : "Ni še zavedenih zaupanja vrednih pošiljateljev.",
     "Could not remove trusted sender {sender}" : "Ni mogoče odstraniti zanesljivega pošiljatelja {sender}",
-    "individual" : "posamično",
-    "domain" : "domena",
     "(organizer)" : " (skliče dogodek)",
     "Untitled event" : "Neimenovan dogodek",
     "Import into {calendar}" : "Uvozi v koledar {calendar}",
@@ -432,6 +419,11 @@ OC.L10N.register(
     "Train" : "Vlak",
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} v {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} v {arrStation}",
+    "Flag" : "Zastavica",
+    "Delete filter" : "Izbriši filter",
+    "Operator" : "Operator",
+    "Actions" : "Dejanja",
+    "Priority" : "Prednost",
     "Mail app" : "Program Pošta",
     "The mail app allows users to read mails on their IMAP accounts." : "Program Mail omogoča uporabnikom branje sporočil z računov IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Na tem mestu so zbrane nastavitve celotnega okolja. Uporabniške nastavitve so v posameznem programu (spodnji levi kot).",
@@ -469,7 +461,6 @@ OC.L10N.register(
     "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} encryption)",
     "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} (šifriranje {ssl})",
     "Configuration for \"{provisioningDomain}\"" : "Nastavitve za »{provisioningDomain}«",
-    "General" : "Splošno",
     "Provisioning domain" : "Domena za povezovanje",
     "Email address template" : "Predloga elektronskega naslova",
     "IMAP" : "IMAP",
@@ -500,9 +491,10 @@ OC.L10N.register(
     "Failed to import the certificate" : "Uvažanje potrdila je spodletelo",
     "Account connected" : "Račun je povezan",
     "Connect your mail account" : "Povežite svoj elektronski račun",
+    "Next week – {timeLocale}" : "Naslednji teden – {timeLocale}",
+    "This weekend – {timeLocale}" : "Ta teden – {timeLocale}",
     "Tomorrow – {timeLocale}" : "Jutri – {timeLocale}",
     "Later today – {timeLocale}" : "Danes – {timeLocale}",
-    "Itinerary for {type} is not supported yet" : "{type} – vrsta prevoza še ni podprta",
     "All" : "Vse",
     "Drafts" : "Osnutki",
     "Favorites" : "Priljubljene",
@@ -533,6 +525,10 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Če vas sistem v nekaj sekundah ne preusmeri samodejno, pritisnite na to mesto.",
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
-    "Continue to %s" : "Nadaljuj na %s"
+    "Continue to %s" : "Nadaljuj na %s",
+    "Sieve filter rules" : "Pravila filtra Sieve",
+    "Sieve filter server" : "Strežnik filtra Sieve",
+    "Account creation" : "Ustvarjanje računa",
+    "Unselect" : "Odstrani izbor"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
